## More Beautiful Python

Make Python more beautiful :) This package includes syntax sugar & tools that you wish were in the standard library.


### Setup

    python -m pip install mbp
    
    > python -m mbp
    ==============================More Beautiful Python==============================
    examples              https://github.com/sudongqi/MoreBeautifulPython/examples.py
    execution_directory   C:\Users\sudon\MoreBeautifulPython
    library_path          C:\Users\sudon\MoreBeautifulPython\src\mbp.py
    cpu_count             16
    version               1.1.0
    =================================================================================


### Examples
https://github.com/sudongqi/MoreBeautifulPython/blob/main/examples.py
*  Alternative for multiprocessing
*  Alternative for logging
*  Syntax sugar for pathlib
* Tools for file loading & handling
* Tools for summarizations
* Tools for simple statistics






